@@ -3,8 +3,6 @@ Define the unit tests for the
 :mod:`colour.models.rgb.transfer_functions.red` module.
 """
 
-import unittest
-
 import numpy as np
 
 from colour.constants import TOLERANCE_ABSOLUTE_TESTS
@@ -49,13 +47,13 @@ __all__ = [
 ]
 
 
-class TestLogEncoding_REDLog(unittest.TestCase):
+class TestLogEncoding_REDLog:
     """
     Define :func:`colour.models.rgb.transfer_functions.red.\
 log_encoding_REDLog` definition unit tests methods.
     """
 
-    def test_log_encoding_REDLog(self):
+    def test_log_encoding_REDLog(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_encoding_REDLog` definition.
@@ -75,7 +73,7 @@ log_encoding_REDLog` definition.
             log_encoding_REDLog(1.0), 1.0, atol=TOLERANCE_ABSOLUTE_TESTS
         )
 
-    def test_n_dimensional_log_encoding_REDLog(self):
+    def test_n_dimensional_log_encoding_REDLog(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_encoding_REDLog` definition n-dimensional arrays support.
@@ -102,7 +100,7 @@ log_encoding_REDLog` definition n-dimensional arrays support.
             log_encoding_REDLog(x), y, atol=TOLERANCE_ABSOLUTE_TESTS
         )
 
-    def test_domain_range_scale_log_encoding_REDLog(self):
+    def test_domain_range_scale_log_encoding_REDLog(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_encoding_REDLog` definition domain and range scale support.
@@ -121,24 +119,22 @@ log_encoding_REDLog` definition domain and range scale support.
                 )
 
     @ignore_numpy_errors
-    def test_nan_log_encoding_REDLog(self):
+    def test_nan_log_encoding_REDLog(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_encoding_REDLog` definition nan support.
         """
 
-        log_encoding_REDLog(
-            np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan])
-        )
+        log_encoding_REDLog(np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan]))
 
 
-class TestLogDecoding_REDLog(unittest.TestCase):
+class TestLogDecoding_REDLog:
     """
     Define :func:`colour.models.rgb.transfer_functions.red.\
 log_decoding_REDLog` definition unit tests methods.
     """
 
-    def test_log_decoding_REDLog(self):
+    def test_log_decoding_REDLog(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_decoding_REDLog` definition.
@@ -158,7 +154,7 @@ log_decoding_REDLog` definition.
             log_decoding_REDLog(1.0), 1.0, atol=TOLERANCE_ABSOLUTE_TESTS
         )
 
-    def test_n_dimensional_log_decoding_REDLog(self):
+    def test_n_dimensional_log_decoding_REDLog(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_decoding_REDLog` definition n-dimensional arrays support.
@@ -185,7 +181,7 @@ log_decoding_REDLog` definition n-dimensional arrays support.
             log_decoding_REDLog(y), x, atol=TOLERANCE_ABSOLUTE_TESTS
         )
 
-    def test_domain_range_scale_log_decoding_REDLog(self):
+    def test_domain_range_scale_log_decoding_REDLog(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_decoding_REDLog` definition domain and range scale support.
@@ -204,24 +200,22 @@ log_decoding_REDLog` definition domain and range scale support.
                 )
 
     @ignore_numpy_errors
-    def test_nan_log_decoding_REDLog(self):
+    def test_nan_log_decoding_REDLog(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_decoding_REDLog` definition nan support.
         """
 
-        log_decoding_REDLog(
-            np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan])
-        )
+        log_decoding_REDLog(np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan]))
 
 
-class TestLogEncoding_REDLogFilm(unittest.TestCase):
+class TestLogEncoding_REDLogFilm:
     """
     Define :func:`colour.models.rgb.transfer_functions.red.\
 log_encoding_REDLogFilm` definition unit tests methods.
     """
 
-    def test_log_encoding_REDLogFilm(self):
+    def test_log_encoding_REDLogFilm(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_encoding_REDLogFilm` definition.
@@ -245,7 +239,7 @@ log_encoding_REDLogFilm` definition.
             atol=TOLERANCE_ABSOLUTE_TESTS,
         )
 
-    def test_n_dimensional_log_encoding_REDLogFilm(self):
+    def test_n_dimensional_log_encoding_REDLogFilm(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_encoding_REDLogFilm` definition n-dimensional arrays support.
@@ -272,7 +266,7 @@ log_encoding_REDLogFilm` definition n-dimensional arrays support.
             log_encoding_REDLogFilm(x), y, atol=TOLERANCE_ABSOLUTE_TESTS
         )
 
-    def test_domain_range_scale_log_encoding_REDLogFilm(self):
+    def test_domain_range_scale_log_encoding_REDLogFilm(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_encoding_REDLogFilm` definition domain and range scale support.
@@ -291,24 +285,22 @@ log_encoding_REDLogFilm` definition domain and range scale support.
                 )
 
     @ignore_numpy_errors
-    def test_nan_log_encoding_REDLogFilm(self):
+    def test_nan_log_encoding_REDLogFilm(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_encoding_REDLogFilm` definition nan support.
         """
 
-        log_encoding_REDLogFilm(
-            np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan])
-        )
+        log_encoding_REDLogFilm(np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan]))
 
 
-class TestLogDecoding_REDLogFilm(unittest.TestCase):
+class TestLogDecoding_REDLogFilm:
     """
     Define :func:`colour.models.rgb.transfer_functions.red.\
 log_decoding_REDLogFilm` definition unit tests methods.
     """
 
-    def test_log_decoding_REDLogFilm(self):
+    def test_log_decoding_REDLogFilm(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_decoding_REDLogFilm` definition.
@@ -332,7 +324,7 @@ log_decoding_REDLogFilm` definition.
             atol=TOLERANCE_ABSOLUTE_TESTS,
         )
 
-    def test_n_dimensional_log_decoding_REDLogFilm(self):
+    def test_n_dimensional_log_decoding_REDLogFilm(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_decoding_REDLogFilm` definition n-dimensional arrays support.
@@ -359,7 +351,7 @@ log_decoding_REDLogFilm` definition n-dimensional arrays support.
             log_decoding_REDLogFilm(y), x, atol=TOLERANCE_ABSOLUTE_TESTS
         )
 
-    def test_domain_range_scale_log_decoding_REDLogFilm(self):
+    def test_domain_range_scale_log_decoding_REDLogFilm(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_decoding_REDLogFilm` definition domain and range scale support.
@@ -378,24 +370,22 @@ log_decoding_REDLogFilm` definition domain and range scale support.
                 )
 
     @ignore_numpy_errors
-    def test_nan_log_decoding_REDLogFilm(self):
+    def test_nan_log_decoding_REDLogFilm(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_decoding_REDLogFilm` definition nan support.
         """
 
-        log_decoding_REDLogFilm(
-            np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan])
-        )
+        log_decoding_REDLogFilm(np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan]))
 
 
-class TestLogEncoding_Log3G10_v1(unittest.TestCase):
+class TestLogEncoding_Log3G10_v1:
     """
     Define :func:`colour.models.rgb.transfer_functions.red.\
 log_encoding_Log3G10_v1` definition unit tests methods.
     """
 
-    def test_log_encoding_Log3G10_v1(self):
+    def test_log_encoding_Log3G10_v1(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_encoding_Log3G10_v1` definition.
@@ -417,7 +407,7 @@ log_encoding_Log3G10_v1` definition.
             atol=TOLERANCE_ABSOLUTE_TESTS,
         )
 
-    def test_n_dimensional_log_encoding_Log3G10_v1(self):
+    def test_n_dimensional_log_encoding_Log3G10_v1(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_encoding_Log3G10_v1` definition n-dimensional arrays support.
@@ -444,7 +434,7 @@ log_encoding_Log3G10_v1` definition n-dimensional arrays support.
             log_encoding_Log3G10_v1(x), y, atol=TOLERANCE_ABSOLUTE_TESTS
         )
 
-    def test_domain_range_scale_log_encoding_Log3G10_v1(self):
+    def test_domain_range_scale_log_encoding_Log3G10_v1(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_encoding_Log3G10_v1` definition domain and range scale support.
@@ -463,24 +453,22 @@ log_encoding_Log3G10_v1` definition domain and range scale support.
                 )
 
     @ignore_numpy_errors
-    def test_nan_log_encoding_Log3G10_v1(self):
+    def test_nan_log_encoding_Log3G10_v1(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_encoding_Log3G10_v1` definition nan support.
         """
 
-        log_encoding_Log3G10_v1(
-            np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan])
-        )
+        log_encoding_Log3G10_v1(np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan]))
 
 
-class TestLogDecoding_Log3G10_v1(unittest.TestCase):
+class TestLogDecoding_Log3G10_v1:
     """
     Define :func:`colour.models.rgb.transfer_functions.red.\
 log_decoding_Log3G10_v1` definition unit tests methods.
     """
 
-    def test_log_decoding_Log3G10_v1(self):
+    def test_log_decoding_Log3G10_v1(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_decoding_Log3G10_v1` definition.
@@ -502,7 +490,7 @@ log_decoding_Log3G10_v1` definition.
             atol=TOLERANCE_ABSOLUTE_TESTS,
         )
 
-    def test_n_dimensional_log_decoding_Log3G10_v1(self):
+    def test_n_dimensional_log_decoding_Log3G10_v1(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_decoding_Log3G10_v1` definition n-dimensional arrays support.
@@ -529,7 +517,7 @@ log_decoding_Log3G10_v1` definition n-dimensional arrays support.
             log_decoding_Log3G10_v1(y), x, atol=TOLERANCE_ABSOLUTE_TESTS
         )
 
-    def test_domain_range_scale_log_decoding_Log3G10_v1(self):
+    def test_domain_range_scale_log_decoding_Log3G10_v1(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_decoding_Log3G10_v1` definition domain and range scale support.
@@ -548,24 +536,22 @@ log_decoding_Log3G10_v1` definition domain and range scale support.
                 )
 
     @ignore_numpy_errors
-    def test_nan_log_decoding_Log3G10_v1(self):
+    def test_nan_log_decoding_Log3G10_v1(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_decoding_Log3G10_v1` definition nan support.
         """
 
-        log_decoding_Log3G10_v1(
-            np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan])
-        )
+        log_decoding_Log3G10_v1(np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan]))
 
 
-class TestLogEncoding_Log3G10_v2(unittest.TestCase):
+class TestLogEncoding_Log3G10_v2:
     """
     Define :func:`colour.models.rgb.transfer_functions.red.\
 log_encoding_Log3G10_v2` definition unit tests methods.
     """
 
-    def test_log_encoding_Log3G10_v2(self):
+    def test_log_encoding_Log3G10_v2(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_encoding_Log3G10_v2` definition.
@@ -589,7 +575,7 @@ log_encoding_Log3G10_v2` definition.
             atol=TOLERANCE_ABSOLUTE_TESTS,
         )
 
-    def test_n_dimensional_log_encoding_Log3G10_v2(self):
+    def test_n_dimensional_log_encoding_Log3G10_v2(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_encoding_Log3G10_v2` definition n-dimensional arrays support.
@@ -616,7 +602,7 @@ log_encoding_Log3G10_v2` definition n-dimensional arrays support.
             log_encoding_Log3G10_v2(x), y, atol=TOLERANCE_ABSOLUTE_TESTS
         )
 
-    def test_domain_range_scale_log_encoding_Log3G10_v2(self):
+    def test_domain_range_scale_log_encoding_Log3G10_v2(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_encoding_Log3G10_v2` definition domain and range scale support.
@@ -635,24 +621,22 @@ log_encoding_Log3G10_v2` definition domain and range scale support.
                 )
 
     @ignore_numpy_errors
-    def test_nan_log_encoding_Log3G10_v2(self):
+    def test_nan_log_encoding_Log3G10_v2(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_encoding_Log3G10_v2` definition nan support.
         """
 
-        log_encoding_Log3G10_v2(
-            np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan])
-        )
+        log_encoding_Log3G10_v2(np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan]))
 
 
-class TestLogDecoding_Log3G10_v2(unittest.TestCase):
+class TestLogDecoding_Log3G10_v2:
     """
     Define :func:`colour.models.rgb.transfer_functions.red.\
 log_decoding_Log3G10_v2` definition unit tests methods.
     """
 
-    def test_log_decoding_Log3G10_v2(self):
+    def test_log_decoding_Log3G10_v2(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_decoding_Log3G10_v2` definition.
@@ -676,7 +660,7 @@ log_decoding_Log3G10_v2` definition.
             atol=TOLERANCE_ABSOLUTE_TESTS,
         )
 
-    def test_n_dimensional_log_decoding_Log3G10_v2(self):
+    def test_n_dimensional_log_decoding_Log3G10_v2(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_decoding_Log3G10_v2` definition n-dimensional arrays support.
@@ -703,7 +687,7 @@ log_decoding_Log3G10_v2` definition n-dimensional arrays support.
             log_decoding_Log3G10_v2(y), x, atol=TOLERANCE_ABSOLUTE_TESTS
         )
 
-    def test_domain_range_scale_log_decoding_Log3G10_v2(self):
+    def test_domain_range_scale_log_decoding_Log3G10_v2(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_decoding_Log3G10_v2` definition domain and range scale support.
@@ -722,24 +706,22 @@ log_decoding_Log3G10_v2` definition domain and range scale support.
                 )
 
     @ignore_numpy_errors
-    def test_nan_log_decoding_Log3G10_v2(self):
+    def test_nan_log_decoding_Log3G10_v2(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_decoding_Log3G10_v2` definition nan support.
         """
 
-        log_decoding_Log3G10_v2(
-            np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan])
-        )
+        log_decoding_Log3G10_v2(np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan]))
 
 
-class TestLogEncoding_Log3G10_v3(unittest.TestCase):
+class TestLogEncoding_Log3G10_v3:
     """
     Define :func:`colour.models.rgb.transfer_functions.red.\
 log_encoding_Log3G10_v3` definition unit tests methods.
     """
 
-    def test_log_encoding_Log3G10_v3(self):
+    def test_log_encoding_Log3G10_v3(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_encoding_Log3G10_v3` definition.
@@ -763,7 +745,7 @@ log_encoding_Log3G10_v3` definition.
             atol=TOLERANCE_ABSOLUTE_TESTS,
         )
 
-    def test_n_dimensional_log_encoding_Log3G10_v3(self):
+    def test_n_dimensional_log_encoding_Log3G10_v3(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_encoding_Log3G10_v3` definition n-dimensional arrays support.
@@ -790,7 +772,7 @@ log_encoding_Log3G10_v3` definition n-dimensional arrays support.
             log_encoding_Log3G10_v3(x), y, atol=TOLERANCE_ABSOLUTE_TESTS
         )
 
-    def test_domain_range_scale_log_encoding_Log3G10_v3(self):
+    def test_domain_range_scale_log_encoding_Log3G10_v3(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_encoding_Log3G10_v3` definition domain and range scale support.
@@ -809,24 +791,22 @@ log_encoding_Log3G10_v3` definition domain and range scale support.
                 )
 
     @ignore_numpy_errors
-    def test_nan_log_encoding_Log3G10_v3(self):
+    def test_nan_log_encoding_Log3G10_v3(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_encoding_Log3G10_v3` definition nan support.
         """
 
-        log_encoding_Log3G10_v3(
-            np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan])
-        )
+        log_encoding_Log3G10_v3(np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan]))
 
 
-class TestLogDecoding_Log3G10_v3(unittest.TestCase):
+class TestLogDecoding_Log3G10_v3:
     """
     Define :func:`colour.models.rgb.transfer_functions.red.\
 log_decoding_Log3G10_v3` definition unit tests methods.
     """
 
-    def test_log_decoding_Log3G10_v3(self):
+    def test_log_decoding_Log3G10_v3(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_decoding_Log3G10_v3` definition.
@@ -850,7 +830,7 @@ log_decoding_Log3G10_v3` definition.
             atol=TOLERANCE_ABSOLUTE_TESTS,
         )
 
-    def test_n_dimensional_log_decoding_Log3G10_v3(self):
+    def test_n_dimensional_log_decoding_Log3G10_v3(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_decoding_Log3G10_v3` definition n-dimensional arrays support.
@@ -877,7 +857,7 @@ log_decoding_Log3G10_v3` definition n-dimensional arrays support.
             log_decoding_Log3G10_v3(y), x, atol=TOLERANCE_ABSOLUTE_TESTS
         )
 
-    def test_domain_range_scale_log_decoding_Log3G10_v3(self):
+    def test_domain_range_scale_log_decoding_Log3G10_v3(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_decoding_Log3G10_v3` definition domain and range scale support.
@@ -896,24 +876,22 @@ log_decoding_Log3G10_v3` definition domain and range scale support.
                 )
 
     @ignore_numpy_errors
-    def test_nan_log_decoding_Log3G10_v3(self):
+    def test_nan_log_decoding_Log3G10_v3(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_decoding_Log3G10_v3` definition nan support.
         """
 
-        log_decoding_Log3G10_v3(
-            np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan])
-        )
+        log_decoding_Log3G10_v3(np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan]))
 
 
-class TestLogEncoding_Log3G12(unittest.TestCase):
+class TestLogEncoding_Log3G12:
     """
     Define :func:`colour.models.rgb.transfer_functions.red.\
 log_encoding_Log3G12` definition unit tests methods.
     """
 
-    def test_log_encoding_Log3G12(self):
+    def test_log_encoding_Log3G12(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_encoding_Log3G12` definition.
@@ -941,7 +919,7 @@ log_encoding_Log3G12` definition.
             atol=TOLERANCE_ABSOLUTE_TESTS,
         )
 
-    def test_n_dimensional_log_encoding_Log3G12(self):
+    def test_n_dimensional_log_encoding_Log3G12(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_encoding_Log3G12` definition n-dimensional arrays support.
@@ -968,7 +946,7 @@ log_encoding_Log3G12` definition n-dimensional arrays support.
             log_encoding_Log3G12(x), y, atol=TOLERANCE_ABSOLUTE_TESTS
         )
 
-    def test_domain_range_scale_log_encoding_Log3G12(self):
+    def test_domain_range_scale_log_encoding_Log3G12(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_encoding_Log3G12` definition domain and range scale support.
@@ -987,24 +965,22 @@ log_encoding_Log3G12` definition domain and range scale support.
                 )
 
     @ignore_numpy_errors
-    def test_nan_log_encoding_Log3G12(self):
+    def test_nan_log_encoding_Log3G12(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_encoding_Log3G12` definition nan support.
         """
 
-        log_encoding_Log3G12(
-            np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan])
-        )
+        log_encoding_Log3G12(np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan]))
 
 
-class TestLogDecoding_Log3G12(unittest.TestCase):
+class TestLogDecoding_Log3G12:
     """
     Define :func:`colour.models.rgb.transfer_functions.red.\
 log_decoding_Log3G12` definition unit tests methods.
     """
 
-    def test_log_decoding_Log3G12(self):
+    def test_log_decoding_Log3G12(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_decoding_Log3G12` definition.
@@ -1032,7 +1008,7 @@ log_decoding_Log3G12` definition.
             atol=TOLERANCE_ABSOLUTE_TESTS,
         )
 
-    def test_n_dimensional_log_decoding_Log3G12(self):
+    def test_n_dimensional_log_decoding_Log3G12(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_decoding_Log3G12` definition n-dimensional arrays support.
@@ -1059,7 +1035,7 @@ log_decoding_Log3G12` definition n-dimensional arrays support.
             log_decoding_Log3G12(y), x, atol=TOLERANCE_ABSOLUTE_TESTS
         )
 
-    def test_domain_range_scale_log_decoding_Log3G12(self):
+    def test_domain_range_scale_log_decoding_Log3G12(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_decoding_Log3G12` definition domain and range scale support.
@@ -1078,16 +1054,10 @@ log_decoding_Log3G12` definition domain and range scale support.
                 )
 
     @ignore_numpy_errors
-    def test_nan_log_decoding_Log3G12(self):
+    def test_nan_log_decoding_Log3G12(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.red.\
 log_decoding_Log3G12` definition nan support.
         """
 
-        log_decoding_Log3G12(
-            np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan])
-        )
-
-
-if __name__ == "__main__":
-    unittest.main()
+        log_decoding_Log3G12(np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan]))
