@@ -3,8 +3,6 @@ Define the unit tests for the
 :mod:`colour.models.rgb.transfer_functions.rimm_romm_rgb` module.
 """
 
-import unittest
-
 import numpy as np
 
 from colour.constants import TOLERANCE_ABSOLUTE_TESTS
@@ -35,13 +33,13 @@ __all__ = [
 ]
 
 
-class TestCctfEncoding_ROMMRGB(unittest.TestCase):
+class TestCctfEncoding_ROMMRGB:
     """
     Define :func:`colour.models.rgb.transfer_functions.rimm_romm_rgb.\
 cctf_encoding_ROMMRGB` definition unit tests methods.
     """
 
-    def test_cctf_encoding_ROMMRGB(self):
+    def test_cctf_encoding_ROMMRGB(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.rimm_romm_rgb.\
 cctf_encoding_ROMMRGB` definition.
@@ -61,13 +59,11 @@ cctf_encoding_ROMMRGB` definition.
             cctf_encoding_ROMMRGB(1.0), 1.0, atol=TOLERANCE_ABSOLUTE_TESTS
         )
 
-        self.assertEqual(cctf_encoding_ROMMRGB(0.18, out_int=True), 98)
+        assert cctf_encoding_ROMMRGB(0.18, out_int=True) == 98
 
-        self.assertEqual(
-            cctf_encoding_ROMMRGB(0.18, bit_depth=12, out_int=True), 1579
-        )
+        assert cctf_encoding_ROMMRGB(0.18, bit_depth=12, out_int=True) == 1579
 
-    def test_n_dimensional_cctf_encoding_ROMMRGB(self):
+    def test_n_dimensional_cctf_encoding_ROMMRGB(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.rimm_romm_rgb.\
 cctf_encoding_ROMMRGB` definition n-dimensional arrays support.
@@ -94,7 +90,7 @@ cctf_encoding_ROMMRGB` definition n-dimensional arrays support.
             cctf_encoding_ROMMRGB(X), X_ROMM, atol=TOLERANCE_ABSOLUTE_TESTS
         )
 
-    def test_domain_range_scale_cctf_encoding_ROMMRGB(self):
+    def test_domain_range_scale_cctf_encoding_ROMMRGB(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.rimm_romm_rgb.\
 cctf_encoding_ROMMRGB` definition domain and range scale support.
@@ -113,24 +109,22 @@ cctf_encoding_ROMMRGB` definition domain and range scale support.
                 )
 
     @ignore_numpy_errors
-    def test_nan_cctf_encoding_ROMMRGB(self):
+    def test_nan_cctf_encoding_ROMMRGB(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.rimm_romm_rgb.\
 cctf_encoding_ROMMRGB` definition nan support.
         """
 
-        cctf_encoding_ROMMRGB(
-            np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan])
-        )
+        cctf_encoding_ROMMRGB(np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan]))
 
 
-class TestCctfDecoding_ROMMRGB(unittest.TestCase):
+class TestCctfDecoding_ROMMRGB:
     """
         Define :func:`colour.models.rgb.transfer_functions.rimm_romm_rgb.
     cctf_decoding_ROMMRGB` definition unit tests methods.
     """
 
-    def test_cctf_decoding_ROMMRGB(self):
+    def test_cctf_decoding_ROMMRGB(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.rimm_romm_rgb.\
 cctf_decoding_ROMMRGB` definition.
@@ -162,7 +156,7 @@ cctf_decoding_ROMMRGB` definition.
             atol=0.001,
         )
 
-    def test_n_dimensional_cctf_decoding_ROMMRGB(self):
+    def test_n_dimensional_cctf_decoding_ROMMRGB(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.rimm_romm_rgb.\
 cctf_decoding_ROMMRGB` definition n-dimensional arrays support.
@@ -189,7 +183,7 @@ cctf_decoding_ROMMRGB` definition n-dimensional arrays support.
             cctf_decoding_ROMMRGB(X_p), X, atol=TOLERANCE_ABSOLUTE_TESTS
         )
 
-    def test_domain_range_scale_cctf_decoding_ROMMRGB(self):
+    def test_domain_range_scale_cctf_decoding_ROMMRGB(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.rimm_romm_rgb.\
 cctf_decoding_ROMMRGB` definition domain and range scale support.
@@ -208,24 +202,22 @@ cctf_decoding_ROMMRGB` definition domain and range scale support.
                 )
 
     @ignore_numpy_errors
-    def test_nan_cctf_decoding_ROMMRGB(self):
+    def test_nan_cctf_decoding_ROMMRGB(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.rimm_romm_rgb.\
 cctf_decoding_ROMMRGB` definition nan support.
         """
 
-        cctf_decoding_ROMMRGB(
-            np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan])
-        )
+        cctf_decoding_ROMMRGB(np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan]))
 
 
-class TestCctfEncoding_RIMMRGB(unittest.TestCase):
+class TestCctfEncoding_RIMMRGB:
     """
     Define :func:`colour.models.rgb.transfer_functions.rimm_romm_rgb.\
 cctf_encoding_RIMMRGB` definition unit tests methods.
     """
 
-    def test_cctf_encoding_RIMMRGB(self):
+    def test_cctf_encoding_RIMMRGB(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.rimm_romm_rgb.\
 cctf_encoding_RIMMRGB` definition.
@@ -247,13 +239,11 @@ cctf_encoding_RIMMRGB` definition.
             atol=TOLERANCE_ABSOLUTE_TESTS,
         )
 
-        self.assertEqual(cctf_encoding_RIMMRGB(0.18, out_int=True), 74)
+        assert cctf_encoding_RIMMRGB(0.18, out_int=True) == 74
 
-        self.assertEqual(
-            cctf_encoding_RIMMRGB(0.18, bit_depth=12, out_int=True), 1194
-        )
+        assert cctf_encoding_RIMMRGB(0.18, bit_depth=12, out_int=True) == 1194
 
-    def test_n_dimensional_cctf_encoding_RIMMRGB(self):
+    def test_n_dimensional_cctf_encoding_RIMMRGB(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.rimm_romm_rgb.\
 cctf_encoding_RIMMRGB` definition n-dimensional arrays support.
@@ -280,7 +270,7 @@ cctf_encoding_RIMMRGB` definition n-dimensional arrays support.
             cctf_encoding_RIMMRGB(X), X_p, atol=TOLERANCE_ABSOLUTE_TESTS
         )
 
-    def test_domain_range_scale_cctf_encoding_RIMMRGB(self):
+    def test_domain_range_scale_cctf_encoding_RIMMRGB(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.rimm_romm_rgb.\
 cctf_encoding_RIMMRGB` definition domain and range scale support.
@@ -299,24 +289,22 @@ cctf_encoding_RIMMRGB` definition domain and range scale support.
                 )
 
     @ignore_numpy_errors
-    def test_nan_cctf_encoding_RIMMRGB(self):
+    def test_nan_cctf_encoding_RIMMRGB(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.rimm_romm_rgb.\
 cctf_encoding_RIMMRGB` definition nan support.
         """
 
-        cctf_encoding_RIMMRGB(
-            np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan])
-        )
+        cctf_encoding_RIMMRGB(np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan]))
 
 
-class TestCctfDecoding_RIMMRGB(unittest.TestCase):
+class TestCctfDecoding_RIMMRGB:
     """
         Define :func:`colour.models.rgb.transfer_functions.rimm_romm_rgb.
     cctf_decoding_RIMMRGB` definition unit tests methods.
     """
 
-    def test_cctf_decoding_RIMMRGB(self):
+    def test_cctf_decoding_RIMMRGB(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.rimm_romm_rgb.\
 cctf_decoding_RIMMRGB` definition.
@@ -350,7 +338,7 @@ cctf_decoding_RIMMRGB` definition.
             atol=0.005,
         )
 
-    def test_n_dimensional_cctf_decoding_RIMMRGB(self):
+    def test_n_dimensional_cctf_decoding_RIMMRGB(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.rimm_romm_rgb.\
 cctf_decoding_RIMMRGB` definition n-dimensional arrays support.
@@ -377,7 +365,7 @@ cctf_decoding_RIMMRGB` definition n-dimensional arrays support.
             cctf_decoding_RIMMRGB(X_p), X, atol=TOLERANCE_ABSOLUTE_TESTS
         )
 
-    def test_domain_range_scale_cctf_decoding_RIMMRGB(self):
+    def test_domain_range_scale_cctf_decoding_RIMMRGB(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.rimm_romm_rgb.\
 cctf_decoding_RIMMRGB` definition domain and range scale support.
@@ -396,24 +384,22 @@ cctf_decoding_RIMMRGB` definition domain and range scale support.
                 )
 
     @ignore_numpy_errors
-    def test_nan_cctf_decoding_RIMMRGB(self):
+    def test_nan_cctf_decoding_RIMMRGB(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.rimm_romm_rgb.\
 cctf_decoding_RIMMRGB` definition nan support.
         """
 
-        cctf_decoding_RIMMRGB(
-            np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan])
-        )
+        cctf_decoding_RIMMRGB(np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan]))
 
 
-class TestLog_encoding_ERIMMRGB(unittest.TestCase):
+class TestLog_encoding_ERIMMRGB:
     """
     Define :func:`colour.models.rgb.transfer_functions.rimm_romm_rgb.\
 log_encoding_ERIMMRGB` definition unit tests methods.
     """
 
-    def test_log_encoding_ERIMMRGB(self):
+    def test_log_encoding_ERIMMRGB(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.rimm_romm_rgb.\
 log_encoding_ERIMMRGB` definition.
@@ -435,13 +421,11 @@ log_encoding_ERIMMRGB` definition.
             atol=TOLERANCE_ABSOLUTE_TESTS,
         )
 
-        self.assertEqual(log_encoding_ERIMMRGB(0.18, out_int=True), 105)
+        assert log_encoding_ERIMMRGB(0.18, out_int=True) == 105
 
-        self.assertEqual(
-            log_encoding_ERIMMRGB(0.18, bit_depth=12, out_int=True), 1679
-        )
+        assert log_encoding_ERIMMRGB(0.18, bit_depth=12, out_int=True) == 1679
 
-    def test_n_dimensional_log_encoding_ERIMMRGB(self):
+    def test_n_dimensional_log_encoding_ERIMMRGB(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.rimm_romm_rgb.\
 log_encoding_ERIMMRGB` definition n-dimensional arrays support.
@@ -468,7 +452,7 @@ log_encoding_ERIMMRGB` definition n-dimensional arrays support.
             log_encoding_ERIMMRGB(X), X_p, atol=TOLERANCE_ABSOLUTE_TESTS
         )
 
-    def test_domain_range_scale_log_encoding_ERIMMRGB(self):
+    def test_domain_range_scale_log_encoding_ERIMMRGB(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.rimm_romm_rgb.\
 log_encoding_ERIMMRGB` definition domain and range scale support.
@@ -487,24 +471,22 @@ log_encoding_ERIMMRGB` definition domain and range scale support.
                 )
 
     @ignore_numpy_errors
-    def test_nan_log_encoding_ERIMMRGB(self):
+    def test_nan_log_encoding_ERIMMRGB(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.rimm_romm_rgb.\
 log_encoding_ERIMMRGB` definition nan support.
         """
 
-        log_encoding_ERIMMRGB(
-            np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan])
-        )
+        log_encoding_ERIMMRGB(np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan]))
 
 
-class TestLog_decoding_ERIMMRGB(unittest.TestCase):
+class TestLog_decoding_ERIMMRGB:
     """
         Define :func:`colour.models.rgb.transfer_functions.rimm_romm_rgb.
     log_decoding_ERIMMRGB` definition unit tests methods.
     """
 
-    def test_log_decoding_ERIMMRGB(self):
+    def test_log_decoding_ERIMMRGB(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.rimm_romm_rgb.\
 log_decoding_ERIMMRGB` definition.
@@ -538,7 +520,7 @@ log_decoding_ERIMMRGB` definition.
             atol=0.005,
         )
 
-    def test_n_dimensional_log_decoding_ERIMMRGB(self):
+    def test_n_dimensional_log_decoding_ERIMMRGB(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.rimm_romm_rgb.\
 log_decoding_ERIMMRGB` definition n-dimensional arrays support.
@@ -565,7 +547,7 @@ log_decoding_ERIMMRGB` definition n-dimensional arrays support.
             log_decoding_ERIMMRGB(X_p), X, atol=TOLERANCE_ABSOLUTE_TESTS
         )
 
-    def test_domain_range_scale_log_decoding_ERIMMRGB(self):
+    def test_domain_range_scale_log_decoding_ERIMMRGB(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.rimm_romm_rgb.\
 log_decoding_ERIMMRGB` definition domain and range scale support.
@@ -584,16 +566,10 @@ log_decoding_ERIMMRGB` definition domain and range scale support.
                 )
 
     @ignore_numpy_errors
-    def test_nan_log_decoding_ERIMMRGB(self):
+    def test_nan_log_decoding_ERIMMRGB(self) -> None:
         """
         Test :func:`colour.models.rgb.transfer_functions.rimm_romm_rgb.\
 log_decoding_ERIMMRGB` definition nan support.
         """
 
-        log_decoding_ERIMMRGB(
-            np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan])
-        )
-
-
-if __name__ == "__main__":
-    unittest.main()
+        log_decoding_ERIMMRGB(np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan]))
